*$ CREATE UDCDRL.FOR
*COPY UDCDRL
*
*=== Udcdrl ===========================================================*
*
      DOUBLE PRECISION FUNCTION UDCDRL ( IJ, KPB, NDCY, UDCDRB, VDCDRB,
     &                                   WDCDRB, BKDCDC, IDCDCB )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 1998-2016      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     User defined DeCay DiRection biasing and Lamda:                  *
*                                                                      *
*     Created on   31 March 1998   by    Alfredo Ferrari & Paola Sala  *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on  10-Apr-16    by    Alfredo Ferrari               *
*                                                                      *
*     Input variables:                                                 *
*                                                                      *
*                  Ij = decaying particle                              *
*                 Kpb = outgoing neutrino                              *
*                Ndcy = number of decay products                       *
*                                                                      *
*     Output variables:                                                *
*                                                                      *
*              Udcdrl = Lamda for direction biasing (1-cos(theta))     *
*          U,V,Wdcdrb = preferential outgoing direction for the neu-   *
*                       trino                                          *
*              Bkdcdc = isotropic background probability               *
*              Idcdcb = algorithm index for direction biasing          *
*                       (0=exponential, 1=1/[1+(x/lamda)^2])           *
*                                                                      *
*                                                                      *
*----------------------------------------------------------------------*
*
      INCLUDE '(TRACKR)'
*
      UDCDRB = ZERZER
      VDCDRB = ZERZER
      WDCDRB = ONEONE
      UDCDRL = ONEFOU
      BKDCDC = ZERZER
      IDCDCB = 0
*
      RETURN
*=== End of subroutine Udcdrl =========================================*
      END

